'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
''
''  Code for "Deep Habits in the New Keynesian Phillips Curve"
''
'' (c)  by Thomas Lubik and Wing Leong Teo
''
'' November 2012
''
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''




smpl 1955Q1 2011Q2

group raw_data rgdp rcons pop gdpdef ulc hour wage

' generate inflation from gdp deflator
genr infl  =log(gdpdef/gdpdef(-1))

' demean the inflation series
genr infl_dm = 100*(infl-@mean(infl))

' generate log gdp deflator
genr  loggdpdef = log(gdpdef)

' generate log unit labor cost
genr logulc  = log(ulc)

' construct rulc using Nason and Smith (2008) approach
genr rulc = 100*(1.10*log(ulc)-log(gdpdef))

' demean the rulc series
genr rulc_dm  =rulc-@mean(rulc)



' generate log real gdp per capita
genr logrgdp_pp = log(rgdp/pop)

' generate log real consumption per capita
genr logrcons_pp = log(rcons/pop)

' generate nominal wage inflation
genr wage_inf=dlog(wage)

' generate constant
genr const=1




' linearly detrend GDP and consumption

' GDP
equation  gdp_detrend.ls logrgdp_pp const @trend

gdp_detrend.makeresids gdp_resids

genr rgdp_dt=100*gdp_resids


' Consumption
equation cons_detrend.ls logrcons_pp const @trend

cons_detrend.makeresids cons_resids

genr rcons_dt = 100*cons_resids


'generate detrended real gdp growth
series drgdp_dt   = rgdp_dt-rgdp_dt(-1)


' generate detrended real consumption growth
series drcons_dt  = rcons_dt-rcons_dt(-1)


' group variables for reporting business cycle statistics
group business_cycle rgdp_dt infl_dm rulc_dm drcons_dt






smpl 1956Q3 2011Q2




' Table 3

param c(1) 0.0 c(2) 0.8 c(3) 0.2 c(4) 0.1 c(5) 0.1 c(6) 0.1

' Unrestricted NKPC
equation standard_NKPC.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)* rulc_dm @ infl_dm(-1 to -4)  rulc_dm(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

' Restricted NKPC
equation restricted_NKPC.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(4)* rulc_dm @ infl_dm(-1 to -4)  rulc_dm(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

' Structural NKPC
scalar bet = 0.99
equation structural_NKPC.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*c(5))*infl_dm(+1)+c(5)/(1+bet*c(5))*infl_dm(-1)+c(6)/(1+bet*c(5))* rulc_dm @ infl_dm(-1 to -4)  rulc_dm(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)



' AR(1) process for mc
equation mc_AR.ls rulc_dm rulc_dm(-1)

' AR(1) process for consumption growth
equation drcons_dt_AR.ls drcons_dt drcons_dt(-1)

' AR(1) parameters from regressions above
scalar rho_mc = 0.98
scalar rho_dc=0.31




' Table 4: Deep Habits NKPC, AR based

scalar sig = 1
scalar epsilo = 2.48
scalar thet_d = 0.85

'construct driving process "d tilda"

series driving_proc=((epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)/(1-thet_d*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d/(1-thet_d)*(1+sig*bet*(thet_d-rho_dc)/(1-thet_d*bet*rho_dc))*drcons_dt) 


'Unrestricted NKPC
equation deep_NKPC_AR.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc  @ infl_dm(-1 to -4) driving_proc(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)



' Restricted NKPC
equation restri_deep_NKPC_AR.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(4)*driving_proc  @ infl_dm(-1 to -4) driving_proc(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


' Structural NKPC
coef(1) eta
coef(1) zet

param eta(1) 0.2 zet(1) 300

equation struc_deep_NKPC_AR.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*eta(1))*infl_dm(+1)+eta(1)/(1+bet*eta(1))*infl_dm(-1)+(epsilo-1)/zet(1)/(1+bet*eta(1))*driving_proc @ infl_dm(-1 to -4) driving_proc(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


' Table 5: Deep Habits NKPC, VAR based


' Estimate the VAR
smpl 1955Q1 2011Q2

equation eq1.ls drcons_dt drcons_dt(-1 to -4) rulc_dm(-1 to -4) drgdp_dt(-1 to -4) const
equation eq2.ls rulc_dm drcons_dt(-1 to -4) rulc_dm(-1 to -4) drgdp_dt(-1 to -4) const
equation eq3.ls drgdp_dt drcons_dt(-1 to -4) rulc_dm(-1 to -4) drgdp_dt(-1 to -4) const



' let's use the variable name + m1 to denote the first row of corresponding to that variable and so on

' delete is used below because if the "objects" have been created before, Eviews will return an error message, not allowing the objects be created again

delete(noerr) drcons_dt_m*
delete(noerr) rulc_m*
delete(noerr) drgdp_dt_m*


' organize the VAR(4) coefficients into matrix of VAR(1) form

vector drcons_dt_m1=@transpose(@subextract(eq1.@coefs, 1, 1, 12, 1))
vector drcons_dt_m2 =@transpose(@unitvector(12,1))
vector drcons_dt_m3 =@transpose(@unitvector(12,2))
vector drcons_dt_m4 =@transpose(@unitvector(12,3))


matrix(4,12) drcons_dt_m_all
rowplace(drcons_dt_m_all, drcons_dt_m1, 1) 
rowplace(drcons_dt_m_all, drcons_dt_m2, 2) 
rowplace(drcons_dt_m_all, drcons_dt_m3, 3) 
rowplace(drcons_dt_m_all, drcons_dt_m4, 4)


vector  rulc_m1=@transpose(@subextract(eq2.@coefs, 1, 1, 12, 1))
vector  rulc_m2 =@transpose(@unitvector(12,5))
vector  rulc_m3 =@transpose(@unitvector(12,6))
vector  rulc_m4 =@transpose(@unitvector(12,7))


matrix(4,12) rulc_m_all
rowplace(rulc_m_all,  rulc_m1, 1) 
rowplace(rulc_m_all,  rulc_m2, 2) 
rowplace(rulc_m_all,  rulc_m3, 3) 
rowplace(rulc_m_all,  rulc_m4, 4)


vector drgdp_dt_m1=@transpose(@subextract(eq3.@coefs, 1, 1, 12, 1))
vector drgdp_dt_m2 =@transpose(@unitvector(12,9))
vector drgdp_dt_m3 =@transpose(@unitvector(12,10))
vector drgdp_dt_m4 =@transpose(@unitvector(12,11))


matrix(4,12) drgdp_dt_m_all
rowplace(drgdp_dt_m_all, drgdp_dt_m1, 1) 
rowplace(drgdp_dt_m_all, drgdp_dt_m2, 2) 
rowplace(drgdp_dt_m_all, drgdp_dt_m3, 3) 
rowplace(drgdp_dt_m_all, drgdp_dt_m4, 4)


delete(noerr) var_matrix

matrix(12,12) var_matrix
matplace(var_matrix, drcons_dt_m_all, 1, 1)
matplace(var_matrix, rulc_m_all, 5, 1)
matplace(var_matrix, drgdp_dt_m_all, 9, 1)


' construct the lambda series from the VAR
delete(noerr) lambd_matrix

matrix lambd_matrix = ((-sig*thet_d*bet/(1-thet_d)*(1-thet_d^2*bet))*@transpose(@unitvector(12,1))*var_matrix - (epsilo*(1-thet_d)*(1-thet_d*bet))*@transpose(@unitvector(12,5)))*@inverse(@identity(12)-thet_d*bet*var_matrix)

series lambd = lambd_matrix(1,1)*drcons_dt + lambd_matrix(1,2)*drcons_dt(-1) + lambd_matrix(1,3)*drcons_dt(-2) + lambd_matrix(1,4)*drcons_dt(-3) +lambd_matrix(1,5)*rulc_dm + lambd_matrix(1,6)*rulc_dm(-1) + lambd_matrix(1,7)*rulc_dm(-2) + lambd_matrix(1,8)*rulc_dm(-3)  + lambd_matrix(1,9)*drgdp_dt+ lambd_matrix(1,10)*drgdp_dt(-1)+ lambd_matrix(1,11)*drgdp_dt(-2)+ lambd_matrix(1,12)*drgdp_dt(-3) + sig*thet_d^2*bet/(1-thet_d)*drcons_dt


' construct the one period ahead consumption growth from VAR, use 'for' to denote 'forward'

delete(noerr) dlogrcons_for_matrix

matrix dlogrcons_for_matrix=@transpose(@unitvector(12,1))*var_matrix


series dlogrcons_for = dlogrcons_for_matrix(1,1)*drcons_dt + dlogrcons_for_matrix(1,2)*drcons_dt(-1) + dlogrcons_for_matrix(1,3)*drcons_dt(-2) + dlogrcons_for_matrix(1,4)*drcons_dt(-3) + dlogrcons_for_matrix(1,5)*rulc_dm + dlogrcons_for_matrix(1,6)*rulc_dm(-1) + dlogrcons_for_matrix(1,7)*rulc_dm(-2)+ dlogrcons_for_matrix(1,8)*rulc_dm(-3)  + dlogrcons_for_matrix(1,9)*drgdp_dt+ dlogrcons_for_matrix(1,10)*drgdp_dt(-1)+ dlogrcons_for_matrix(1,11)*drgdp_dt(-2)+ dlogrcons_for_matrix(1,12)*drgdp_dt(-3)



' construct the one period ahead lambda series from VAR, use 'for' to denote 'forward'

delete(noerr)  lambd_for_matrix

matrix lambd_for_matrix = ((-sig*thet_d*bet/(1-thet_d)*(1-thet_d^2*bet))*@transpose(@unitvector(12,1))*var_matrix*var_matrix - (epsilo*(1-thet_d)*(1-thet_d*bet))*@transpose(@unitvector(12,5))*var_matrix)*@inverse(@identity(12)-thet_d*bet*var_matrix)


series lambd_for = lambd_for_matrix(1,1)*drcons_dt + lambd_for_matrix(1,2)*drcons_dt(-1) + lambd_for_matrix(1,3)*drcons_dt(-2) + lambd_for_matrix(1,4)*drcons_dt(-3) +lambd_for_matrix(1,5)*rulc_dm + lambd_for_matrix(1,6)*rulc_dm(-1) + lambd_for_matrix(1,7)*rulc_dm(-2) + lambd_for_matrix(1,8)*rulc_dm(-3)  + lambd_for_matrix(1,9)*drgdp_dt+ lambd_for_matrix(1,10)*drgdp_dt(-1)+ lambd_for_matrix(1,11)*drgdp_dt(-2)+ lambd_for_matrix(1,12)*drgdp_dt(-3) + sig*thet_d^2*bet/(1-thet_d)*dlogrcons_for

series driving_proc_var = (epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)*rulc_dm + sig*bet*thet_d/(1-thet_d)/(epsilo-1)*dlogrcons_for -(1+sig*bet*thet_d)*thet_d/(1-thet_d)/(epsilo-1)*drcons_dt - thet_d*bet/(epsilo-1)*lambd_for


' estimate the VAR based NKPC
smpl 1956Q3 2011Q2



param c(1) 0.0 c(2) 0.5 c(3) 0.5 c(4) 0.05

equation deep_NKPC_var.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc_var  @ infl_dm(-1 to -4) driving_proc_var(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

param c(1) 0.0 c(2) 0.5 c(3) 0.5 c(4) 0.05

equation restri_deep_NKPC_var.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(4)*driving_proc_var  @ infl_dm(-1 to -4) driving_proc_var(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

param c(7) 0.001 c(8) 150
equation struc_deep_NKPC_var.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*c(7))*infl_dm(+1)+c(7)/(1+bet*c(7))*infl_dm(-1)+(epsilo-1)/c(8)/(1+bet*c(7))*driving_proc_var  @ infl_dm(-1 to -4) driving_proc_var(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)



' Table 6: Alternative specifications

' Unrestricted NKPC
equation deep_NKPC_as.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*rulc_dm-c(5)*drcons_dt @ infl_dm(-1 to -4) rulc_dm(-1 to -2) drcons_dt(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

param c(1) 0.0 c(2) 0.5 c(3) 0.5 c(4) 0.05 c(5) 0.1


' restricted NKPC
equation restri_deep_NKPC_as.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(4)*rulc_dm-c(5)*drcons_dt @ infl_dm(-1 to -4) rulc_dm(-1 to -2) drcons_dt(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

' Structural NKPC
coef(1) thet_d2

param thet_d2(1) 0.85 eta(1) 0.2 zet(1) 300


scalar sig = 1
scalar epsilo=2.48
equation struc_deep_NKPC_as_1.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*eta(1))*infl_dm(+1)+eta(1)/(1+bet*eta(1))*infl_dm(-1)+(epsilo-1)/zet(1)/(1+bet*eta(1))*((epsilo*(1-thet_d2(1))-(1-thet_d2(1)*bet))/(epsilo-1)/(1-thet_d2(1)*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d2(1)/(1-thet_d2(1))*(1+sig*bet*(thet_d2(1)-rho_dc)/(1-thet_d2(1)*bet*rho_dc))*drcons_dt) @ infl_dm(-1 to -4) rulc_dm(-1 to -2) drcons_dt(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


scalar sig = 3
scalar epsilo=2.48
equation struc_deep_NKPC_as_2.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*eta(1))*infl_dm(+1)+eta(1)/(1+bet*eta(1))*infl_dm(-1)+(epsilo-1)/zet(1)/(1+bet*eta(1))*((epsilo*(1-thet_d2(1))-(1-thet_d2(1)*bet))/(epsilo-1)/(1-thet_d2(1)*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d2(1)/(1-thet_d2(1))*(1+sig*bet*(thet_d2(1)-rho_dc)/(1-thet_d2(1)*bet*rho_dc))*drcons_dt) @ infl_dm(-1 to -4) rulc_dm(-1 to -2) drcons_dt(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


scalar sig = 3
scalar epsilo=11
equation struc_deep_NKPC_as_3.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*eta(1))*infl_dm(+1)+eta(1)/(1+bet*eta(1))*infl_dm(-1)+(epsilo-1)/zet(1)/(1+bet*eta(1))*((epsilo*(1-thet_d2(1))-(1-thet_d2(1)*bet))/(epsilo-1)/(1-thet_d2(1)*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d2(1)/(1-thet_d2(1))*(1+sig*bet*(thet_d2(1)-rho_dc)/(1-thet_d2(1)*bet*rho_dc))*drcons_dt) @ infl_dm(-1 to -4) rulc_dm(-1 to -2) drcons_dt(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


' Table 7:  Robustness

smpl 1956Q3 2011Q2

scalar sig = 1
scalar epsilo = 2.48
scalar thet_d = 0.15


'construct driving process "d tilda"

series driving_proc1=((epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)/(1-thet_d*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d/(1-thet_d)*(1+sig*bet*(thet_d-rho_dc)/(1-thet_d*bet*rho_dc))*drcons_dt) 


'Unrestricted NKPC, use AC to denote alternative calibration
equation deep_NKPC_AC_1.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc1  @ infl_dm(-1 to -4) driving_proc1(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)



scalar sig = 1
scalar epsilo = 2.48
scalar thet_d = 0.95

'construct driving process "d tilda"

series driving_proc2=((epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)/(1-thet_d*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d/(1-thet_d)*(1+sig*bet*(thet_d-rho_dc)/(1-thet_d*bet*rho_dc))*drcons_dt) 


'Unrestricted NKPC, use AC to denote alternative calibration
equation deep_NKPC_AC_2.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc2  @ infl_dm(-1 to -4) driving_proc2(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


scalar sig = 1
scalar epsilo = 2.48
scalar thet_d = 0.60

'construct driving process "d tilda"

series driving_proc3=((epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)/(1-thet_d*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d/(1-thet_d)*(1+sig*bet*(thet_d-rho_dc)/(1-thet_d*bet*rho_dc))*drcons_dt) 


'Unrestricted NKPC, use AC to denote alternative calibration
equation deep_NKPC_AC_3.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc3  @ infl_dm(-1 to -4) driving_proc3(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


scalar sig = 3
scalar epsilo = 2.48
scalar thet_d = 0.85

'construct driving process "d tilda"

series driving_proc4=((epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)/(1-thet_d*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d/(1-thet_d)*(1+sig*bet*(thet_d-rho_dc)/(1-thet_d*bet*rho_dc))*drcons_dt) 


'Unrestricted NKPC, use AC to denote alternative calibration
equation deep_NKPC_AC_4.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc4  @ infl_dm(-1 to -4) driving_proc4(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


scalar sig = 1
scalar epsilo = 11
scalar thet_d = 0.85

'construct driving process "d tilda"

series driving_proc5=((epsilo*(1-thet_d)-(1-thet_d*bet))/(epsilo-1)/(1-thet_d*bet*rho_mc)*rulc_dm-1/(epsilo-1)*thet_d/(1-thet_d)*(1+sig*bet*(thet_d-rho_dc)/(1-thet_d*bet*rho_dc))*drcons_dt) 


'Unrestricted NKPC, use AC to denote alternative calibration
equation deep_NKPC_AC_5.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc5  @ infl_dm(-1 to -4) driving_proc5(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)


' Table 8: Sub-sample
smpl 1984Q1 2011Q2

' Panel A: Standard NKPC
' Unrestricted NKPC
equation standard_NKPC_sub.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)* rulc_dm @ infl_dm(-1 to -4)  rulc_dm(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

' Restricted NKPC
equation restricted_NKPC_sub.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(4)* rulc_dm @ infl_dm(-1 to -4)  rulc_dm(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

' Structural NKPC
scalar bet = 0.99
equation structural_NKPC_sub.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*c(5))*infl_dm(+1)+c(5)/(1+bet*c(5))*infl_dm(-1)+c(6)/(1+bet*c(5))* rulc_dm @ infl_dm(-1 to -4)  rulc_dm(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)



' Panel B: Deep Habits NKPC
equation deep_NKPC_var_sub.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(3)*infl_dm(-1)+c(4)*driving_proc_var  @ infl_dm(-1 to -4) driving_proc_var(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)



equation restri_deep_NKPC_var_sub.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+c(2)*infl_dm(+1)+c(4)*driving_proc_var  @ infl_dm(-1 to -4) driving_proc_var(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

scalar sig = 1
scalar epsilo = 2.48
scalar thet_d = 0.85

equation struc_deep_NKPC_var_sub.gmm(method=converge,instwgt=hac,instkern=bart,instbw=neweywest,cov=hac,covkern=bart,covbw=neweywest) infl_dm=c(1)+bet/(1+bet*c(7))*infl_dm(+1)+c(7)/(1+bet*c(7))*infl_dm(-1)+(epsilo-1)/c(8)/(1+bet*c(7))*driving_proc_var  @ infl_dm(-1 to -4) driving_proc_var(-1 to -2) rgdp_dt(-1 to -2) wage_inf(-1 to -2)

